@@ -10,7 +10,7 @@ our @EXPORT_OK = qw( get_vimeo_list_info get_youtube_list_info get_new_video_url
 
 use JSON             qw( decode_json );
 use LWP::UserAgent   qw();
-#use Mojo::DOM       qw(); # required
+use Mojo::DOM        qw();
 use Term::ANSIScreen qw( :screen );
 
 use if $^O eq 'MSWin32', 'Win32::Console::ANSI';
@@ -28,7 +28,6 @@ sub get_youtube_list_info {
         timeout       => $opt->{timeout},
         show_progress => 1
     );
-    require Mojo::DOM;
     my $tmp = [];
     my $next;
     my $count = 0;
@@ -141,7 +140,6 @@ sub get_vimeo_list_info {
         timeout       => $opt->{timeout},
         show_progress => 1
     );
-    require Mojo::DOM;
     my $tmp = [];
     my $next;
     my $count = 0;
