@@ -6,7 +6,7 @@ use strict;
 use 5.010000;
 
 use Exporter qw( import );
-our @EXPORT_OK = qw( sec_to_time get_filename timestamp_to_upload_date encode_fs check_mapping_stdout
+our @EXPORT_OK = qw( sec_to_time get_filename timestamp_to_upload_date encode_fs check_mapping_stdout format_bytes_per_sec
                     write_json read_json sanitize_for_path uni_capture uni_system HIDE_CURSOR SHOW_CURSOR );
 
 use Encode             qw( encode FB_CROAK LEAVE_SRC );
@@ -109,6 +109,26 @@ sub check_mapping_stdout {
 }
 
 
+sub format_bytes_per_sec {
+    my ( $val ) = @_;
+    return '--k/s' if ! $val;
+    $val /= 1024;
+    return '--k/s' if $val < 1;
+    for my $unit ( 'k', 'M', 'G' ) {
+        if ( length int $val > 3 ) {
+            $val /= 1024;
+            next;
+        }
+        elsif ( $val < 10 && $unit ne 'k' ) {
+            return sprintf "%0.1f%s/s", $val, $unit;
+        }
+        else {
+            return sprintf "%d%s/s", $val, $unit;
+        }
+    }
+}
+
+
 sub uni_capture {
     my ( @cmd ) = @_;
     if ( wantarray ) {
